# backuppurge

Selectively purge daily full backups, but keeping some:

- Keep all daily backups for the last X days
- Keep one daily backup per month for the last Y months
- Keep one yearly backup per year for the last Z years

Backup file names must have YYYY-MM-DD in their filename somewhere (in that format) and must have the same prefix/postfix, e.g.:

    homedir_2013-03-31.tgz
    homedir_2013-03-30.tgz
    ...

# Documentation

Usage information can be found in the manual page.

# Dependencies

- Python 3.2 OR Python >= 2.6 with argparse
- Optional: Nose for running unit tests
- Optional: Docutils for updating the documentation

# Running Tests

To run the test suite:

    nosetests

# Updating the documentation

To convert the README file to a website and to update the manual page:

    python update_docs.py

# Download

- Source tarball: backuppurge-1.0.2.tar.gz
- Development version: http://github.com/thp/backuppurge/

# Website

http://thp.io/2013/backuppurge/

# License

Simplified BSD License

Thomas Perl | contact info | thp.io | 2013